summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/explain.h
diff options
context:
space:
mode:
authorDavid Storch <david.storch@10gen.com>2014-12-12 11:39:33 -0500
committerDavid Storch <david.storch@10gen.com>2014-12-12 12:58:51 -0500
commita3ec06066d1db2e593744089cf17d93e5225131e (patch)
tree2bac3bf7da8608b1757f7bcc93732510c24466ba /src/mongo/db/query/explain.h
parent5120700460ef7a3240603a4307a0b1be2c358c3c (diff)
downloadmongo-a3ec06066d1db2e593744089cf17d93e5225131e.tar.gz
SERVER-16068 add namespace to explain output
Diffstat (limited to 'src/mongo/db/query/explain.h')
-rw-r--r--src/mongo/db/query/explain.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/query/explain.h b/src/mongo/db/query/explain.h
index 31ef77f03bd..888df375a03 100644
--- a/src/mongo/db/query/explain.h
+++ b/src/mongo/db/query/explain.h
@@ -161,11 +161,11 @@ namespace mongo {
*
* This is a helper for generating explain BSON. It is used by explainStages(...).
*
* @param query -- the query part of the operation being explained.
* @param winnerStats -- the stats tree for the winning plan.
* @param rejectedStats -- an array of stats trees, one per rejected plan
*/
- static void generatePlannerInfo(CanonicalQuery* query,
+ static void generatePlannerInfo(PlanExecutor* exec,
PlanStageStats* winnerStats,
const vector<PlanStageStats*>& rejectedStats,
BSONObjBuilder* out);
@@ -161,11 +161,11 @@ namespace mongo {
* This is a helper for generating explain BSON. It is used by explainStages(...).
*
- * @param query -- the query part of the operation being explained.
+ * @param exec -- the stage tree for the operation being explained.
* @param winnerStats -- the stats tree for the winning plan.
* @param rejectedStats -- an array of stats trees, one per rejected plan